@@ -47,6 +47,8 @@ static const PropertyInfo propertiesInfo[] =
        { BeagleSearch::Image, "fixme:colortype", I18N_NOOP("Color type: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:Name", 0 },
        { BeagleSearch::Contact, "fixme:Email1", 0 },
+       { BeagleSearch::Contact, "vCard:FN", 0 },
+       { BeagleSearch::Contact, "vCard:EMAIL", 0 },
        { BeagleSearch::Contact, "fixme:BusinessPhone", I18N_NOOP("Business phone: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:HomePhone", I18N_NOOP("Home phone: %1")"<br>" },
        { BeagleSearch::Contact, "fixme:MobilePhone", I18N_NOOP("Mobile phone: %1")"<br>" },
