@@ -375,8 +375,10 @@ void SearchDlg::updateStatus()
     else
        text=i18n("Results <b>%1 through %2 of %3</b> are shown.").arg(displayOffset+1).arg(displayOffset+tableHits->count()).arg(displayed_results.count());
 
+#if 0
     if (still_searching)
        text=text+" <b>"+i18n("(still searching)")+"</b>";
+#endif
 
     labelStatus->setText(text);
 }
@@ -431,14 +433,22 @@ void SearchDlg::search()
 
     m_searchPixmap->setMovie(QMovie(locate( "appdata", "search-running.mng" )));
 
+    new_results.clear();
+
+    kdDebug() << "searchProgramList" << endl;
     searchProgramList(QString::null);
 
+    kdDebug() << "searchBookmars" << endl;
     if (!bookmarkManager)
       bookmarkManager = KBookmarkManager::userBookmarksManager();
     searchBookmarks(bookmarkManager->root());
 
+    kdDebug() << "searchAddressBook" << endl;
     searchAddressbook();
 
+    displayResults(new_results);
+
+    kdDebug() << "starting BeagleSearch" << endl;
     beagle_search = new BeagleSearch(current_beagle_client_id, this, current_query.get());
     beagle_search->start();
     still_searching = true;
@@ -525,7 +535,7 @@ void SearchDlg::customEvent (QCustomEvent *e)
 	    toclean_client_list.append (client);
 	    kdDebug () << "Scheduling client to be deleted in 500ms" << endl;
 	    toclean_list_mutex.unlock ();
-	    QTimer::singleShot (500, this, SLOT (cleanClientList ()));
+	    QTimer::singleShot (500, this, SLOT (slotCleanClientList ()));
 	}
     }
 }
@@ -709,14 +719,32 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         item->setIcon("kaddressbook");
 
         QStringList _properties(result->properties);
-        QString name = takeProperty("fixme:Name",_properties);
-        QString email = takeProperty("fixme:Email1",_properties);
+        QString name = takeProperty("vCard:FN",_properties);
+        QString email = takeProperty("vCard:EMAIL",_properties);
 
         QString properties;
         BeagleSearch::PropertyList::iterator it;
         for ( it = _properties.begin(); it != _properties.end(); ++it )
                 properties=properties+(*it);
 
+        if (!m_addressBook)
+           m_addressBook = KABC::StdAddressBook::self( false );
+
+        KABC::Addressee addresseee = m_addressBook->findByUid( item->uri().mid(8,10) );
+        QString number;
+
+        number = addresseee.phoneNumber(KABC::PhoneNumber::Work).number();
+        if (!number.isEmpty())
+           properties=properties+i18n("Business phone: %1").arg(number)+"<br>";
+
+        number = addresseee.phoneNumber(KABC::PhoneNumber::Cell).number();
+        if (!number.isEmpty())
+           properties=properties+i18n("Mobile phone: %1").arg(number)+"<br>";
+
+        number = addresseee.phoneNumber(KABC::PhoneNumber::Home).number();
+        if (!number.isEmpty())
+           properties=properties+i18n("Home phone: %1").arg(number)+"<br>";
+
         if (!properties.isEmpty())
            item->setDescriptionText("<qt>"+properties+"</qt>");
 
@@ -726,15 +754,17 @@ void SearchDlg::insertResult(BeagleSearch::beagle_result_struct *result,int inde
         item->insertHeaderWidget(0,headerNameLabel);
         connect(headerNameLabel, SIGNAL(leftClickedURL()), SLOT(slotOpen()));
 
-        QLabel *headerLabel = new QLabel(item);
-        headerLabel->setText(i18n(","));
-        item->insertHeaderWidget(1,headerLabel);
-
-        KerryLabel *headerEmailLabel = new KerryLabel(item);
-        headerEmailLabel->setText(email);
-        headerEmailLabel->setURL(email);
-        item->insertHeaderWidget(2,headerEmailLabel);
-        connect(headerEmailLabel, SIGNAL(leftClickedURL(const QString&)), SLOT(slotMailTo(const QString&)));
+        if (!email.isEmpty()) {
+        	QLabel *headerLabel = new QLabel(item);
+        	headerLabel->setText(i18n(","));
+        	item->insertHeaderWidget(1,headerLabel);
+		
+        	KerryLabel *headerEmailLabel = new KerryLabel(item);
+        	headerEmailLabel->setText(email);
+        	headerEmailLabel->setURL(email);
+        	item->insertHeaderWidget(2,headerEmailLabel);
+        	connect(headerEmailLabel, SIGNAL(leftClickedURL(const QString&)), SLOT(slotMailTo(const QString&)));
+        }
       }
       else if (*(result->mime_type)=="message/rfc822" || (*(result->uri)).startsWith("email:/") ) {
         item->setIcon("mail_generic");
@@ -1079,7 +1109,7 @@ void SearchDlg::searchHasOutput(BeagleSearch::BeagleResultList &items)
           KURL kurl(*(result->uri));
           *(result->uri)=kurl.url();
       }
-      if (!checkUriInResults(*(result->uri)) && !(*(result->uri)).startsWith("kabc:/") && !(*(result->uri)).startsWith("kbookmark:/")) {
+      if (!checkUriInResults(*(result->uri)) && !(*(result->uri)).startsWith("kbookmark:/")) {
          result->show_expanded=showBigTiles;
          results.append(result);
          searchResults->append(result);
@@ -1245,7 +1275,7 @@ void SearchDlg::slotOpen()
       }
       else if (item->uri().startsWith("kabc:/") )
       {
-        slotOpenKAddressBook(item->uri().mid(7,10));
+        slotOpenKAddressBook(item->uri().mid(8,10));
       }
       else if (item->uri().startsWith("knotes:/") )
       {
@@ -1646,10 +1676,7 @@ void SearchDlg::searchProgramList(QString relPath)
 				result->score = 0.0;
 				result->show_expanded=showBigTiles;
 				results.append(result);
-
-				BeagleSearch::BeagleResultList* searchResults = new BeagleSearch::BeagleResultList;
-				searchResults->append(result);
-				displayResults(*searchResults);
+				new_results.append(result);
 			}
 		}
 	}
@@ -1691,10 +1718,7 @@ void SearchDlg::searchBookmarks(KBookmarkGroup group)
 				result->score = 0.0;
 				result->show_expanded=showBigTiles;
 				results.append(result);
-
-				BeagleSearch::BeagleResultList* searchResults = new BeagleSearch::BeagleResultList;
-				searchResults->append(result);
-				displayResults(*searchResults);
+				new_results.append(result);
 		}
 		bookmark = group.next(bookmark);
 	}
@@ -1712,7 +1736,7 @@ void SearchDlg::searchAddressbook()
             continue;
         }
 
-        if (checkUriInResults("kabc://"+(*it).uid()+"/")) {
+        if (checkUriInResults("kabc:///"+(*it).uid())) {
              it++;
              continue;
         }
@@ -1723,17 +1747,14 @@ void SearchDlg::searchAddressbook()
 
 	BeagleSearch::beagle_result_struct *result = new BeagleSearch::beagle_result_struct;
 	result->mime_type=new QString("text/html");
-        result->uri=new QString("kabc://"+(*it).uid()+"/");
-	*(result->properties).append("fixme:Name="+realName);
-        *(result->properties).append("fixme:Email1="+(*it).preferredEmail());
+        result->uri=new QString("kabc:///"+(*it).uid());
+	*(result->properties).append("vCard:FN="+realName);
+        *(result->properties).append("vCard:EMAIL="+(*it).preferredEmail());
 	result->tilegroup = BeagleSearch::Contact;
 	result->score = 0.0;
 	result->show_expanded=showBigTiles;
 	results.append(result);
-
-	BeagleSearch::BeagleResultList* searchResults = new BeagleSearch::BeagleResultList;
-	searchResults->append(result);
-	displayResults(*searchResults);
+	new_results.append(result);
 
        it++;
     }
